@@ -55,7 +55,7 @@ DISPLAY_TIME_FORMAT = '%Y-%m-%d %H:%M:%S UTC'
 PARSE_TIME_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
 PARSE_TIME_FORMAT_WITH_USEC = '%Y-%m-%dT%H:%M:%S.%fZ'
 
-DB_SUBPATH = 'world/os/x86_64/world.db'
+DB_SUBPATH = 'system/os/x86_64/system.db'
 
 MIRROR_URL_FORMAT = '{0}{1}/os/{2}'
 MIRRORLIST_ENTRY_FORMAT = "Server = " + MIRROR_URL_FORMAT + "\n"
